@@ -352,7 +352,9 @@ pub struct LinuxCpu {
     mems: Option<String>,
 }
 
-#[derive(Builder, Clone, Copy, Debug, Default, Deserialize, Eq, Getters, PartialEq, Serialize)]
+#[derive(
+    Builder, Clone, Copy, Debug, Default, Deserialize, Eq, CopyGetters, PartialEq, Serialize,
+)]
 #[builder(
     default,
     pattern = "owned",
@@ -565,7 +567,7 @@ pub struct LinuxResources {
     devices: Option<Vec<LinuxDeviceCgroup>>,
 
     #[serde(default, skip_serializing_if = "Option::is_none")]
-    #[getset(get_copy = "pub")]
+    #[getset(get = "pub")]
     /// Memory restriction configuration.
     memory: Option<LinuxMemory>,
 
@@ -575,7 +577,7 @@ pub struct LinuxResources {
     cpu: Option<LinuxCpu>,
 
     #[serde(default, skip_serializing_if = "Option::is_none")]
-    #[getset(get_copy = "pub")]
+    #[getset(get = "pub")]
     /// Task resource restrictions
     pids: Option<LinuxPids>,
 
